@@ -23,7 +23,7 @@ use Net::Intermapper::Vertice;
 BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $ERROR %_CHANGED);
-    $VERSION     = '0.03';
+    $VERSION     = '0.04';
     @ISA         = qw(Exporter);
     @EXPORT      = qw();
     @EXPORT_OK   = qw();
@@ -88,6 +88,12 @@ has 'cache' => (
 	default => sub { "1" }, # Cache any request
 );
 
+has 'mock' => (
+	is => 'rw',
+	isa => 'Int',
+	default => sub { "0" },
+);
+
 sub users # No Moose here :(
 { my $self = shift;
   $ERROR = "";
@@ -97,12 +103,15 @@ sub users # No Moose here :(
 	#$self->{"Users"} = $args{"users"}; 
 	$self->{"Users"} = $_[0]; # Expect a hash ref to be passed
 	# Yes, this code is slightly based of the Net::Cisco::ACS code so may be some of it is weird
-	# Are you really reading the comments now? 
+	# Are you really reading the comments now?
+    if ($self->mock())
+    { return $self->{"Users"}; }
   } else
   { if (!$self->cache) # No caching? Always reload
-	{ $self->{"Users"} = $self->query("users"); }
+	{ $self->{"Users"} = $self->query("users") unless $self->mock; }
 	else
-	{ $self->{"Users"} = $self->query("users") if $_CHANGED{"users"}; # Only reload if changed
+	{ if (!$self->mock)
+      { $self->{"Users"} = $self->query("users") if $_CHANGED{"users"}; } # Only reload if changed
 	} 
   }
   return wantarray ? % { $self->{"Users"} } : $self->{"Users"};
@@ -193,7 +202,6 @@ sub query
   $hostname .= "/~export/$type.$format"; 
   my $request = HTTP::Request->new("GET" => $hostname);
   my $useragent = LWP::UserAgent->new (ssl_opts => $self->ssl_options);
-
   my $result = $useragent->request($request);
   if ($result->code eq "400") { $ERROR = "Bad Request - HTTP Status: 400"; }
   if ($result->code eq "410") { $ERROR = "Unknown $type queried by name or ID - HTTP Status: 410"; }  
