@@ -5,13 +5,13 @@ use Moose;
 BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS @HEADERS);
-    $VERSION     = '0.03';
+    $VERSION     = '0.04';
     @ISA         = qw(Exporter);
     @EXPORT      = qw();
     @EXPORT_OK   = qw();
     %EXPORT_TAGS = ();
 	
-	@HEADERS = qw(Id Name Password External Guest Groups);
+	@HEADERS = qw(Id Name Password Guest External Groups);
 };
 
 # MOOSE!
@@ -42,13 +42,13 @@ has 'Password' => (
 has 'Guest' => (
 	is => 'rw',
 	isa => 'Str',
-	default => sub { "false"; },
+	default => sub { ""; },
 	);
 
 has 'External' => (
 	is => 'rw',
 	isa => 'Str',
-	default => sub { ""; },
+	default => sub { "false"; },
 	);
 
 has 'mode' => ( # create, update, delete
@@ -64,8 +64,8 @@ sub toXML
   my $id = $self->Id;
   my $name = $self->Name || "";
   my $groups = $self->Groups || "Read_only";  
-  my $external = $self->External || "";
-  my $guest = $self->Guest || "true";      
+  my $external = $self->External || "false";
+  my $guest = $self->Guest || ""; 
   my $password = $self->Password || "&#0;";
   my $result = "";
   # Need to build the XML formatting!!
@@ -86,14 +86,17 @@ sub toCSV
   { if ($self->mode eq "create")
     { next if $key eq "Id";
 	  next if $key eq "mode";
+      next unless $attributes{$key};
       $result .= $attributes{$key}.","; 
 	}
 	if ($self->mode eq "update")
     { next if $key eq "mode";
+      next unless $attributes{$key};
 	  $result .= $attributes{$key}.","; 
 	}
 	if ($self->mode eq "delete")
     { next if $key eq "mode";
+      next unless $attributes{$key};
 	  next unless $attributes{$key};
 	  $result .= $attributes{$key}.","; 
 	}
