@@ -3,6 +3,8 @@
 use lib qw(Net/Intermapper/lib);
 use Net::Intermapper;
 use Data::Dumper;
+use warnings;
+use strict;
 
 my $intermapper = Net::Intermapper->new(hostname=>"10.0.0.1", username=>"admin", password=>"nmsadmin");
 print Dumper $intermapper->users;
